@@ -3,6 +3,8 @@ package Config::Any::Perl;
 use strict;
 use warnings;
 
+use base 'Config::Any::Base';
+
 my %cache;
 
 =head1 NAME
@@ -47,23 +49,13 @@ sub load {
     my $content;
 
     unless ( $content = $cache{ $file } ) {
-        $content = eval { require $file };
+        $content = require $file;
         $cache{ $file } = $content;
     }
 
     return $content;
 }
 
-=head2 is_supported( )
-
-Returns true.
-
-=cut
-
-sub is_supported {
-    return 1;
-}
-
 =head1 AUTHOR
 
 Brian Cassidy E<lt>bricas@cpan.orgE<gt>
